@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef AutoCorrection_H
@@ -84,7 +72,7 @@ public:
     Q_REQUIRED_RESULT QSet<QString> twoUpperLetterExceptions() const;
     Q_REQUIRED_RESULT QHash<QString, QString> autocorrectEntries() const;
 
-    Q_REQUIRED_RESULT bool autocorrect(bool htmlMode, QTextDocument &document, int &position);
+    bool autocorrect(bool htmlMode, QTextDocument &document, int &position);
     void writeConfig();
 
     Q_REQUIRED_RESULT bool addAutoCorrect(const QString &currentWord, const QString &replaceWord);
@@ -120,24 +108,24 @@ private:
     bool excludeToUppercase(const QString &word) const;
     QColor linkColor();
 
-    bool mSingleSpaces; // suppress double spaces.
-    bool mUppercaseFirstCharOfSentence; // convert first letter of a sentence automaticall to uppercase
-    bool mFixTwoUppercaseChars;  // convert two uppercase characters to one upper and one lowercase.
-    bool mAutoFractions; // replace 1/2 with ½
-    bool mCapitalizeWeekDays;
-    bool mAdvancedAutocorrect; // autocorrection from a list of entries
+    bool mSingleSpaces = true; // suppress double spaces.
+    bool mUppercaseFirstCharOfSentence = false; // convert first letter of a sentence automaticall to uppercase
+    bool mFixTwoUppercaseChars = false;  // convert two uppercase characters to one upper and one lowercase.
+    bool mAutoFractions = true; // replace 1/2 with ½
+    bool mCapitalizeWeekDays = false;
+    bool mAdvancedAutocorrect = false; // autocorrection from a list of entries
 
-    bool mReplaceDoubleQuotes;  // replace double quotes with typographical quotes
-    bool mReplaceSingleQuotes;  // replace single quotes with typographical quotes
+    bool mReplaceDoubleQuotes = false;  // replace double quotes with typographical quotes
+    bool mReplaceSingleQuotes = false;  // replace single quotes with typographical quotes
 
-    bool mAutoFormatUrl;
-    bool mAutoBoldUnderline;
-    bool mEnabled;
-    bool mSuperScriptAppendix;
+    bool mAutoFormatUrl = false;
+    bool mAutoBoldUnderline = false;
+    bool mEnabled = false;
+    bool mSuperScriptAppendix = false;
 
-    bool mAddNonBreakingSpace;
-    int mMaxFindStringLenght;
-    int mMinFindStringLenght;
+    bool mAddNonBreakingSpace = false;
+    int mMaxFindStringLenght = 0;
+    int mMinFindStringLenght = 0;
     QString mWord;
     QTextCursor mCursor;
     QChar mNonBreakingSpace;
